import React, { useState } from 'react';
import { Modal, Table, Button, Space, Tooltip, message, Typography } from 'antd';
import { CopyOutlined, PlayCircleOutlined, DownloadOutlined, LinkOutlined, QrcodeOutlined } from '@ant-design/icons';
import { WeComPlan } from '@src/views/publishContent/weCom/type'; // Assuming type location
import copy from 'copy-to-clipboard';
import { getShareQrPic } from '@src/http/api';
import http from '@src/http';
import modal from 'antd/es/modal';
import VideoPlayModal from '../videoPlayModal';

// import QRCode from 'qrcode.react'; // Consider adding this dependency if not present

const { Text } = Typography;

interface LinkDetailModalProps {
  visible: boolean;
  onClose: () => void;
  videos: WeComPlan[]; // Use the appropriate type for your video data
}

// --- Placeholder Functions (Implement actual logic later) ---


const downloadCover = (video: WeComPlan) => {
  if (video.cover) {
    const link = document.createElement('a');
    link.href = video.cover;
    // Attempt to infer filename, might need refinement
    const filename = video.cover.substring(video.cover.lastIndexOf('/') + 1) || `cover_${video.id}.jpg`;
    link.download = filename;
    link.target = '_blank'; // Open in new tab might be safer for some browsers
    link.rel = 'noopener noreferrer';
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  } else {
     message.warning('No cover image URL available.');
  }
};

const copyPushLink = (video: WeComPlan) => {
  // Assuming video object might have a 'pushLink' property added by the parent component
  const linkToCopy = video.pageUrl || 'Push link not available'; // Updated placeholder
  if (video.pageUrl && copy(linkToCopy)) {
    message.success('推送链接已复制');
  } else if (!video.pageUrl) {
    message.warning('没有可复制的推送链接');
  } else {
    message.error('复制失败');
  }
};

const showQRCode = (video: WeComPlan) => {
  http.get<string>(getShareQrPic, {
		params: {
			pageUrl: video.pageUrl,
		}
	}).then(res => {
		modal.info({
			title: '二维码',
			content: <img src={res.data} alt="二维码" />,
		});
	}).catch(err => {
		message.error(err.msg || '获取二维码失败');
	});
};
// --- End Placeholder Functions ---


const LinkDetailModal: React.FC<LinkDetailModalProps> = ({ visible, onClose, videos }) => {
	const [isVideoPlayModalVisible, setIsVideoPlayModalVisible] = useState<boolean>(false);
	const [activeVideo, setActiveVideo] = useState<WeComPlan | null>(null);
  const columns = [
    {
      title: '视频标题',
      dataIndex: 'title',
      key: 'title',
      render: (title: string) => (
        <Space>
          <Text style={{ maxWidth: 200 }} ellipsis={{ tooltip: title }}>{title}</Text>
          <Tooltip title="复制标题">
            <Button
              type="text"
              icon={<CopyOutlined />}
              onClick={() => {
                if (copy(title)) {
                  message.success('标题已复制');
                } else {
                  message.error('复制失败');
                }
              }}
              size="small"
            />
          </Tooltip>
        </Space>
      ),
    },
    {
      title: '场景',
      dataIndex: 'scene',
      key: 'scene',
      render: (scene: number | undefined) => (scene === 0 ? '群发' : scene === 1 ? '单发' : '未知'), // Adjust based on your scene values
    },
    {
      title: '操作',
      key: 'action',
      render: (_: any, record: WeComPlan) => (
        <Space wrap size="small">
          <Button type="link" icon={<PlayCircleOutlined />} onClick={() => playVideo(record)} size="small">播放</Button>
          <Button type="link" icon={<DownloadOutlined />} onClick={() => downloadCover(record)} size="small">下载封面</Button>
          <Button type="link" icon={<LinkOutlined />} onClick={() => copyPushLink(record)} size="small">复制推送链接</Button>
          <Button type="link" icon={<QrcodeOutlined />} onClick={() => showQRCode(record)} size="small">二维码</Button>
        </Space>
      ),
    },
	];
	
	const playVideo = (video: WeComPlan) => {
		setActiveVideo(video);
		setIsVideoPlayModalVisible(true);
	};

  return (
    <Modal
      title="链接详情"
      open={visible}
      onCancel={onClose}
      footer={[
        <Button key="close" onClick={onClose}>
          关闭
        </Button>,
      ]}
      width={800} // Adjust width as needed
      destroyOnClose
    >
      <Table
        columns={columns}
        dataSource={videos.map(v => ({ ...v, key: v.id }))} // Ensure each item has a unique key
        pagination={false} // Disable pagination if the list is expected to be short
        size="small"
			/>
			<VideoPlayModal
				visible={isVideoPlayModalVisible}
				onClose={() => setIsVideoPlayModalVisible(false)}
				videoUrl={activeVideo?.video || ''}
				title={activeVideo?.title || ''}
			/>
    </Modal>
  );
};

export default LinkDetailModal; 
